@@ -25,6 +25,7 @@ from .type_defs import (
     CreatePipelineOutputTypeDef,
     DescribeObjectsOutputTypeDef,
     DescribePipelinesOutputTypeDef,
+    EmptyResponseMetadataTypeDef,
     EvaluateExpressionOutputTypeDef,
     FieldTypeDef,
     GetPipelineDefinitionOutputTypeDef,
@@ -90,7 +91,7 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        parameterValues: Sequence["ParameterValueTypeDef"] = ...,
+        parameterValues: Sequence[ParameterValueTypeDef] = ...,
         startTimestamp: Union[datetime, str] = ...
     ) -> Dict[str, Any]:
         """
@@ -100,7 +101,7 @@ class DataPipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client/#activate_pipeline)
         """
 
-    def add_tags(self, *, pipelineId: str, tags: Sequence["TagTypeDef"]) -> Dict[str, Any]:
+    def add_tags(self, *, pipelineId: str, tags: Sequence[TagTypeDef]) -> Dict[str, Any]:
         """
         Adds or modifies tags for the specified pipeline.
 
@@ -116,13 +117,16 @@ class DataPipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/datapipeline.html#DataPipeline.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client/#close)
+        """
+
     def create_pipeline(
-        self,
-        *,
-        name: str,
-        uniqueId: str,
-        description: str = ...,
-        tags: Sequence["TagTypeDef"] = ...
+        self, *, name: str, uniqueId: str, description: str = ..., tags: Sequence[TagTypeDef] = ...
     ) -> CreatePipelineOutputTypeDef:
         """
         Creates a new, empty pipeline.
@@ -139,7 +143,7 @@ class DataPipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client/#deactivate_pipeline)
         """
 
-    def delete_pipeline(self, *, pipelineId: str) -> None:
+    def delete_pipeline(self, *, pipelineId: str) -> EmptyResponseMetadataTypeDef:
         """
         Deletes a pipeline, its pipeline definition, and its run history.
 
@@ -219,7 +223,7 @@ class DataPipelineClient(BaseClient):
         *,
         workerGroup: str,
         hostname: str = ...,
-        instanceIdentity: "InstanceIdentityTypeDef" = ...
+        instanceIdentity: InstanceIdentityTypeDef = ...
     ) -> PollForTaskOutputTypeDef:
         """
         Task runners call `PollForTask` to receive a task to perform from AWS Data
@@ -233,9 +237,9 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        pipelineObjects: Sequence["PipelineObjectTypeDef"],
-        parameterObjects: Sequence["ParameterObjectTypeDef"] = ...,
-        parameterValues: Sequence["ParameterValueTypeDef"] = ...
+        pipelineObjects: Sequence[PipelineObjectTypeDef],
+        parameterObjects: Sequence[ParameterObjectTypeDef] = ...,
+        parameterValues: Sequence[ParameterValueTypeDef] = ...
     ) -> PutPipelineDefinitionOutputTypeDef:
         """
         Adds tasks, schedules, and preconditions to the specified pipeline.
@@ -249,7 +253,7 @@ class DataPipelineClient(BaseClient):
         *,
         pipelineId: str,
         sphere: str,
-        query: "QueryTypeDef" = ...,
+        query: QueryTypeDef = ...,
         marker: str = ...,
         limit: int = ...
     ) -> QueryObjectsOutputTypeDef:
@@ -270,7 +274,7 @@ class DataPipelineClient(BaseClient):
         """
 
     def report_task_progress(
-        self, *, taskId: str, fields: Sequence["FieldTypeDef"] = ...
+        self, *, taskId: str, fields: Sequence[FieldTypeDef] = ...
     ) -> ReportTaskProgressOutputTypeDef:
         """
         Task runners call `ReportTaskProgress` when assigned a task to acknowledge that
@@ -291,7 +295,9 @@ class DataPipelineClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datapipeline/client/#report_task_runner_heartbeat)
         """
 
-    def set_status(self, *, pipelineId: str, objectIds: Sequence[str], status: str) -> None:
+    def set_status(
+        self, *, pipelineId: str, objectIds: Sequence[str], status: str
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Requests that the status of the specified physical or logical pipeline objects
         be updated in the specified pipeline.
@@ -321,9 +327,9 @@ class DataPipelineClient(BaseClient):
         self,
         *,
         pipelineId: str,
-        pipelineObjects: Sequence["PipelineObjectTypeDef"],
-        parameterObjects: Sequence["ParameterObjectTypeDef"] = ...,
-        parameterValues: Sequence["ParameterValueTypeDef"] = ...
+        pipelineObjects: Sequence[PipelineObjectTypeDef],
+        parameterObjects: Sequence[ParameterObjectTypeDef] = ...,
+        parameterValues: Sequence[ParameterValueTypeDef] = ...
     ) -> ValidatePipelineDefinitionOutputTypeDef:
         """
         Validates the specified pipeline definition to ensure that it is well formed and
