@@ -6,9 +6,9 @@ Type annotations for datapipeline service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_datapipeline.type_defs import ActivatePipelineInputRequestTypeDef
+    from mypy_boto3_datapipeline.type_defs import ParameterValueTypeDef
 
-    data: ActivatePipelineInputRequestTypeDef = {...}
+    data: ParameterValueTypeDef = {...}
     ```
 """
 import sys
@@ -24,117 +24,84 @@ else:
 
 
 __all__ = (
+    "ParameterValueTypeDef",
+    "TagTypeDef",
+    "ResponseMetadataTypeDef",
+    "DeactivatePipelineInputRequestTypeDef",
+    "DeletePipelineInputRequestTypeDef",
+    "PaginatorConfigTypeDef",
+    "DescribeObjectsInputRequestTypeDef",
+    "DescribePipelinesInputRequestTypeDef",
+    "EvaluateExpressionInputRequestTypeDef",
+    "FieldTypeDef",
+    "GetPipelineDefinitionInputRequestTypeDef",
+    "InstanceIdentityTypeDef",
+    "ListPipelinesInputRequestTypeDef",
+    "PipelineIdNameTypeDef",
+    "OperatorTypeDef",
+    "ParameterAttributeTypeDef",
+    "ValidationErrorTypeDef",
+    "ValidationWarningTypeDef",
+    "RemoveTagsInputRequestTypeDef",
+    "ReportTaskRunnerHeartbeatInputRequestTypeDef",
+    "SetStatusInputRequestTypeDef",
+    "SetTaskStatusInputRequestTypeDef",
     "ActivatePipelineInputRequestTypeDef",
     "AddTagsInputRequestTypeDef",
     "CreatePipelineInputRequestTypeDef",
     "CreatePipelineOutputTypeDef",
-    "DeactivatePipelineInputRequestTypeDef",
-    "DeletePipelineInputRequestTypeDef",
-    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
-    "DescribeObjectsInputRequestTypeDef",
-    "DescribeObjectsOutputTypeDef",
-    "DescribePipelinesInputRequestTypeDef",
-    "DescribePipelinesOutputTypeDef",
-    "EvaluateExpressionInputRequestTypeDef",
+    "EmptyResponseMetadataTypeDef",
     "EvaluateExpressionOutputTypeDef",
-    "FieldTypeDef",
-    "GetPipelineDefinitionInputRequestTypeDef",
-    "GetPipelineDefinitionOutputTypeDef",
-    "InstanceIdentityTypeDef",
+    "QueryObjectsOutputTypeDef",
+    "ReportTaskProgressOutputTypeDef",
+    "ReportTaskRunnerHeartbeatOutputTypeDef",
+    "DescribeObjectsInputDescribeObjectsPaginateTypeDef",
     "ListPipelinesInputListPipelinesPaginateTypeDef",
-    "ListPipelinesInputRequestTypeDef",
-    "ListPipelinesOutputTypeDef",
-    "OperatorTypeDef",
-    "PaginatorConfigTypeDef",
-    "ParameterAttributeTypeDef",
-    "ParameterObjectTypeDef",
-    "ParameterValueTypeDef",
     "PipelineDescriptionTypeDef",
-    "PipelineIdNameTypeDef",
     "PipelineObjectTypeDef",
+    "ReportTaskProgressInputRequestTypeDef",
     "PollForTaskInputRequestTypeDef",
-    "PollForTaskOutputTypeDef",
-    "PutPipelineDefinitionInputRequestTypeDef",
+    "ListPipelinesOutputTypeDef",
+    "SelectorTypeDef",
+    "ParameterObjectTypeDef",
     "PutPipelineDefinitionOutputTypeDef",
+    "ValidatePipelineDefinitionOutputTypeDef",
+    "DescribePipelinesOutputTypeDef",
+    "DescribeObjectsOutputTypeDef",
+    "TaskObjectTypeDef",
+    "QueryTypeDef",
+    "GetPipelineDefinitionOutputTypeDef",
+    "PutPipelineDefinitionInputRequestTypeDef",
+    "ValidatePipelineDefinitionInputRequestTypeDef",
+    "PollForTaskOutputTypeDef",
     "QueryObjectsInputQueryObjectsPaginateTypeDef",
     "QueryObjectsInputRequestTypeDef",
-    "QueryObjectsOutputTypeDef",
-    "QueryTypeDef",
-    "RemoveTagsInputRequestTypeDef",
-    "ReportTaskProgressInputRequestTypeDef",
-    "ReportTaskProgressOutputTypeDef",
-    "ReportTaskRunnerHeartbeatInputRequestTypeDef",
-    "ReportTaskRunnerHeartbeatOutputTypeDef",
-    "ResponseMetadataTypeDef",
-    "SelectorTypeDef",
-    "SetStatusInputRequestTypeDef",
-    "SetTaskStatusInputRequestTypeDef",
+)
+
+ParameterValueTypeDef = TypedDict(
+    "ParameterValueTypeDef",
+    {
+        "id": str,
+        "stringValue": str,
+    },
+)
+
+TagTypeDef = TypedDict(
     "TagTypeDef",
-    "TaskObjectTypeDef",
-    "ValidatePipelineDefinitionInputRequestTypeDef",
-    "ValidatePipelineDefinitionOutputTypeDef",
-    "ValidationErrorTypeDef",
-    "ValidationWarningTypeDef",
-)
-
-_RequiredActivatePipelineInputRequestTypeDef = TypedDict(
-    "_RequiredActivatePipelineInputRequestTypeDef",
     {
-        "pipelineId": str,
-    },
-)
-_OptionalActivatePipelineInputRequestTypeDef = TypedDict(
-    "_OptionalActivatePipelineInputRequestTypeDef",
-    {
-        "parameterValues": Sequence["ParameterValueTypeDef"],
-        "startTimestamp": Union[datetime, str],
-    },
-    total=False,
-)
-
-
-class ActivatePipelineInputRequestTypeDef(
-    _RequiredActivatePipelineInputRequestTypeDef, _OptionalActivatePipelineInputRequestTypeDef
-):
-    pass
-
-
-AddTagsInputRequestTypeDef = TypedDict(
-    "AddTagsInputRequestTypeDef",
-    {
-        "pipelineId": str,
-        "tags": Sequence["TagTypeDef"],
+        "key": str,
+        "value": str,
     },
 )
 
-_RequiredCreatePipelineInputRequestTypeDef = TypedDict(
-    "_RequiredCreatePipelineInputRequestTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "name": str,
-        "uniqueId": str,
-    },
-)
-_OptionalCreatePipelineInputRequestTypeDef = TypedDict(
-    "_OptionalCreatePipelineInputRequestTypeDef",
-    {
-        "description": str,
-        "tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreatePipelineInputRequestTypeDef(
-    _RequiredCreatePipelineInputRequestTypeDef, _OptionalCreatePipelineInputRequestTypeDef
-):
-    pass
-
-
-CreatePipelineOutputTypeDef = TypedDict(
-    "CreatePipelineOutputTypeDef",
-    {
-        "pipelineId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
@@ -166,30 +133,16 @@ DeletePipelineInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
-    "_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "pipelineId": str,
-        "objectIds": Sequence[str],
-    },
-)
-_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
-    "_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef",
-    {
-        "evaluateExpressions": bool,
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
 
-
-class DescribeObjectsInputDescribeObjectsPaginateTypeDef(
-    _RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef,
-    _OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef,
-):
-    pass
-
-
 _RequiredDescribeObjectsInputRequestTypeDef = TypedDict(
     "_RequiredDescribeObjectsInputRequestTypeDef",
     {
@@ -213,16 +166,6 @@ class DescribeObjectsInputRequestTypeDef(
     pass
 
 
-DescribeObjectsOutputTypeDef = TypedDict(
-    "DescribeObjectsOutputTypeDef",
-    {
-        "pipelineObjects": List["PipelineObjectTypeDef"],
-        "marker": str,
-        "hasMoreResults": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribePipelinesInputRequestTypeDef = TypedDict(
     "DescribePipelinesInputRequestTypeDef",
     {
@@ -230,14 +173,6 @@ DescribePipelinesInputRequestTypeDef = TypedDict(
     },
 )
 
-DescribePipelinesOutputTypeDef = TypedDict(
-    "DescribePipelinesOutputTypeDef",
-    {
-        "pipelineDescriptionList": List["PipelineDescriptionTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 EvaluateExpressionInputRequestTypeDef = TypedDict(
     "EvaluateExpressionInputRequestTypeDef",
     {
@@ -247,14 +182,6 @@ EvaluateExpressionInputRequestTypeDef = TypedDict(
     },
 )
 
-EvaluateExpressionOutputTypeDef = TypedDict(
-    "EvaluateExpressionOutputTypeDef",
-    {
-        "evaluatedExpression": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredFieldTypeDef = TypedDict(
     "_RequiredFieldTypeDef",
     {
@@ -297,16 +224,6 @@ class GetPipelineDefinitionInputRequestTypeDef(
     pass
 
 
-GetPipelineDefinitionOutputTypeDef = TypedDict(
-    "GetPipelineDefinitionOutputTypeDef",
-    {
-        "pipelineObjects": List["PipelineObjectTypeDef"],
-        "parameterObjects": List["ParameterObjectTypeDef"],
-        "parameterValues": List["ParameterValueTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 InstanceIdentityTypeDef = TypedDict(
     "InstanceIdentityTypeDef",
     {
@@ -316,14 +233,6 @@ InstanceIdentityTypeDef = TypedDict(
     total=False,
 )
 
-ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
-    "ListPipelinesInputListPipelinesPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 ListPipelinesInputRequestTypeDef = TypedDict(
     "ListPipelinesInputRequestTypeDef",
     {
@@ -332,14 +241,13 @@ ListPipelinesInputRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListPipelinesOutputTypeDef = TypedDict(
-    "ListPipelinesOutputTypeDef",
+PipelineIdNameTypeDef = TypedDict(
+    "PipelineIdNameTypeDef",
     {
-        "pipelineIdList": List["PipelineIdNameTypeDef"],
-        "marker": str,
-        "hasMoreResults": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "id": str,
+        "name": str,
     },
+    total=False,
 )
 
 OperatorTypeDef = TypedDict(
@@ -351,16 +259,6 @@ OperatorTypeDef = TypedDict(
     total=False,
 )
 
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
-    },
-    total=False,
-)
-
 ParameterAttributeTypeDef = TypedDict(
     "ParameterAttributeTypeDef",
     {
@@ -369,190 +267,20 @@ ParameterAttributeTypeDef = TypedDict(
     },
 )
 
-ParameterObjectTypeDef = TypedDict(
-    "ParameterObjectTypeDef",
+ValidationErrorTypeDef = TypedDict(
+    "ValidationErrorTypeDef",
     {
         "id": str,
-        "attributes": List["ParameterAttributeTypeDef"],
+        "errors": List[str],
     },
+    total=False,
 )
 
-ParameterValueTypeDef = TypedDict(
-    "ParameterValueTypeDef",
+ValidationWarningTypeDef = TypedDict(
+    "ValidationWarningTypeDef",
     {
         "id": str,
-        "stringValue": str,
-    },
-)
-
-_RequiredPipelineDescriptionTypeDef = TypedDict(
-    "_RequiredPipelineDescriptionTypeDef",
-    {
-        "pipelineId": str,
-        "name": str,
-        "fields": List["FieldTypeDef"],
-    },
-)
-_OptionalPipelineDescriptionTypeDef = TypedDict(
-    "_OptionalPipelineDescriptionTypeDef",
-    {
-        "description": str,
-        "tags": List["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class PipelineDescriptionTypeDef(
-    _RequiredPipelineDescriptionTypeDef, _OptionalPipelineDescriptionTypeDef
-):
-    pass
-
-
-PipelineIdNameTypeDef = TypedDict(
-    "PipelineIdNameTypeDef",
-    {
-        "id": str,
-        "name": str,
-    },
-    total=False,
-)
-
-PipelineObjectTypeDef = TypedDict(
-    "PipelineObjectTypeDef",
-    {
-        "id": str,
-        "name": str,
-        "fields": List["FieldTypeDef"],
-    },
-)
-
-_RequiredPollForTaskInputRequestTypeDef = TypedDict(
-    "_RequiredPollForTaskInputRequestTypeDef",
-    {
-        "workerGroup": str,
-    },
-)
-_OptionalPollForTaskInputRequestTypeDef = TypedDict(
-    "_OptionalPollForTaskInputRequestTypeDef",
-    {
-        "hostname": str,
-        "instanceIdentity": "InstanceIdentityTypeDef",
-    },
-    total=False,
-)
-
-
-class PollForTaskInputRequestTypeDef(
-    _RequiredPollForTaskInputRequestTypeDef, _OptionalPollForTaskInputRequestTypeDef
-):
-    pass
-
-
-PollForTaskOutputTypeDef = TypedDict(
-    "PollForTaskOutputTypeDef",
-    {
-        "taskObject": "TaskObjectTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_RequiredPutPipelineDefinitionInputRequestTypeDef",
-    {
-        "pipelineId": str,
-        "pipelineObjects": Sequence["PipelineObjectTypeDef"],
-    },
-)
-_OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
-    "_OptionalPutPipelineDefinitionInputRequestTypeDef",
-    {
-        "parameterObjects": Sequence["ParameterObjectTypeDef"],
-        "parameterValues": Sequence["ParameterValueTypeDef"],
-    },
-    total=False,
-)
-
-
-class PutPipelineDefinitionInputRequestTypeDef(
-    _RequiredPutPipelineDefinitionInputRequestTypeDef,
-    _OptionalPutPipelineDefinitionInputRequestTypeDef,
-):
-    pass
-
-
-PutPipelineDefinitionOutputTypeDef = TypedDict(
-    "PutPipelineDefinitionOutputTypeDef",
-    {
-        "validationErrors": List["ValidationErrorTypeDef"],
-        "validationWarnings": List["ValidationWarningTypeDef"],
-        "errored": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
-    "_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef",
-    {
-        "pipelineId": str,
-        "sphere": str,
-    },
-)
-_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
-    "_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef",
-    {
-        "query": "QueryTypeDef",
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class QueryObjectsInputQueryObjectsPaginateTypeDef(
-    _RequiredQueryObjectsInputQueryObjectsPaginateTypeDef,
-    _OptionalQueryObjectsInputQueryObjectsPaginateTypeDef,
-):
-    pass
-
-
-_RequiredQueryObjectsInputRequestTypeDef = TypedDict(
-    "_RequiredQueryObjectsInputRequestTypeDef",
-    {
-        "pipelineId": str,
-        "sphere": str,
-    },
-)
-_OptionalQueryObjectsInputRequestTypeDef = TypedDict(
-    "_OptionalQueryObjectsInputRequestTypeDef",
-    {
-        "query": "QueryTypeDef",
-        "marker": str,
-        "limit": int,
-    },
-    total=False,
-)
-
-
-class QueryObjectsInputRequestTypeDef(
-    _RequiredQueryObjectsInputRequestTypeDef, _OptionalQueryObjectsInputRequestTypeDef
-):
-    pass
-
-
-QueryObjectsOutputTypeDef = TypedDict(
-    "QueryObjectsOutputTypeDef",
-    {
-        "ids": List[str],
-        "marker": str,
-        "hasMoreResults": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-QueryTypeDef = TypedDict(
-    "QueryTypeDef",
-    {
-        "selectors": Sequence["SelectorTypeDef"],
+        "warnings": List[str],
     },
     total=False,
 )
@@ -565,35 +293,6 @@ RemoveTagsInputRequestTypeDef = TypedDict(
     },
 )
 
-_RequiredReportTaskProgressInputRequestTypeDef = TypedDict(
-    "_RequiredReportTaskProgressInputRequestTypeDef",
-    {
-        "taskId": str,
-    },
-)
-_OptionalReportTaskProgressInputRequestTypeDef = TypedDict(
-    "_OptionalReportTaskProgressInputRequestTypeDef",
-    {
-        "fields": Sequence["FieldTypeDef"],
-    },
-    total=False,
-)
-
-
-class ReportTaskProgressInputRequestTypeDef(
-    _RequiredReportTaskProgressInputRequestTypeDef, _OptionalReportTaskProgressInputRequestTypeDef
-):
-    pass
-
-
-ReportTaskProgressOutputTypeDef = TypedDict(
-    "ReportTaskProgressOutputTypeDef",
-    {
-        "canceled": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredReportTaskRunnerHeartbeatInputRequestTypeDef = TypedDict(
     "_RequiredReportTaskRunnerHeartbeatInputRequestTypeDef",
     {
@@ -617,34 +316,6 @@ class ReportTaskRunnerHeartbeatInputRequestTypeDef(
     pass
 
 
-ReportTaskRunnerHeartbeatOutputTypeDef = TypedDict(
-    "ReportTaskRunnerHeartbeatOutputTypeDef",
-    {
-        "terminate": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-SelectorTypeDef = TypedDict(
-    "SelectorTypeDef",
-    {
-        "fieldName": str,
-        "operator": "OperatorTypeDef",
-    },
-    total=False,
-)
-
 SetStatusInputRequestTypeDef = TypedDict(
     "SetStatusInputRequestTypeDef",
     {
@@ -678,11 +349,278 @@ class SetTaskStatusInputRequestTypeDef(
     pass
 
 
-TagTypeDef = TypedDict(
-    "TagTypeDef",
+_RequiredActivatePipelineInputRequestTypeDef = TypedDict(
+    "_RequiredActivatePipelineInputRequestTypeDef",
     {
-        "key": str,
-        "value": str,
+        "pipelineId": str,
+    },
+)
+_OptionalActivatePipelineInputRequestTypeDef = TypedDict(
+    "_OptionalActivatePipelineInputRequestTypeDef",
+    {
+        "parameterValues": Sequence[ParameterValueTypeDef],
+        "startTimestamp": Union[datetime, str],
+    },
+    total=False,
+)
+
+
+class ActivatePipelineInputRequestTypeDef(
+    _RequiredActivatePipelineInputRequestTypeDef, _OptionalActivatePipelineInputRequestTypeDef
+):
+    pass
+
+
+AddTagsInputRequestTypeDef = TypedDict(
+    "AddTagsInputRequestTypeDef",
+    {
+        "pipelineId": str,
+        "tags": Sequence[TagTypeDef],
+    },
+)
+
+_RequiredCreatePipelineInputRequestTypeDef = TypedDict(
+    "_RequiredCreatePipelineInputRequestTypeDef",
+    {
+        "name": str,
+        "uniqueId": str,
+    },
+)
+_OptionalCreatePipelineInputRequestTypeDef = TypedDict(
+    "_OptionalCreatePipelineInputRequestTypeDef",
+    {
+        "description": str,
+        "tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreatePipelineInputRequestTypeDef(
+    _RequiredCreatePipelineInputRequestTypeDef, _OptionalCreatePipelineInputRequestTypeDef
+):
+    pass
+
+
+CreatePipelineOutputTypeDef = TypedDict(
+    "CreatePipelineOutputTypeDef",
+    {
+        "pipelineId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EvaluateExpressionOutputTypeDef = TypedDict(
+    "EvaluateExpressionOutputTypeDef",
+    {
+        "evaluatedExpression": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+QueryObjectsOutputTypeDef = TypedDict(
+    "QueryObjectsOutputTypeDef",
+    {
+        "ids": List[str],
+        "marker": str,
+        "hasMoreResults": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ReportTaskProgressOutputTypeDef = TypedDict(
+    "ReportTaskProgressOutputTypeDef",
+    {
+        "canceled": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ReportTaskRunnerHeartbeatOutputTypeDef = TypedDict(
+    "ReportTaskRunnerHeartbeatOutputTypeDef",
+    {
+        "terminate": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "_RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef",
+    {
+        "pipelineId": str,
+        "objectIds": Sequence[str],
+    },
+)
+_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef = TypedDict(
+    "_OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef",
+    {
+        "evaluateExpressions": bool,
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeObjectsInputDescribeObjectsPaginateTypeDef(
+    _RequiredDescribeObjectsInputDescribeObjectsPaginateTypeDef,
+    _OptionalDescribeObjectsInputDescribeObjectsPaginateTypeDef,
+):
+    pass
+
+
+ListPipelinesInputListPipelinesPaginateTypeDef = TypedDict(
+    "ListPipelinesInputListPipelinesPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+_RequiredPipelineDescriptionTypeDef = TypedDict(
+    "_RequiredPipelineDescriptionTypeDef",
+    {
+        "pipelineId": str,
+        "name": str,
+        "fields": List[FieldTypeDef],
+    },
+)
+_OptionalPipelineDescriptionTypeDef = TypedDict(
+    "_OptionalPipelineDescriptionTypeDef",
+    {
+        "description": str,
+        "tags": List[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class PipelineDescriptionTypeDef(
+    _RequiredPipelineDescriptionTypeDef, _OptionalPipelineDescriptionTypeDef
+):
+    pass
+
+
+PipelineObjectTypeDef = TypedDict(
+    "PipelineObjectTypeDef",
+    {
+        "id": str,
+        "name": str,
+        "fields": List[FieldTypeDef],
+    },
+)
+
+_RequiredReportTaskProgressInputRequestTypeDef = TypedDict(
+    "_RequiredReportTaskProgressInputRequestTypeDef",
+    {
+        "taskId": str,
+    },
+)
+_OptionalReportTaskProgressInputRequestTypeDef = TypedDict(
+    "_OptionalReportTaskProgressInputRequestTypeDef",
+    {
+        "fields": Sequence[FieldTypeDef],
+    },
+    total=False,
+)
+
+
+class ReportTaskProgressInputRequestTypeDef(
+    _RequiredReportTaskProgressInputRequestTypeDef, _OptionalReportTaskProgressInputRequestTypeDef
+):
+    pass
+
+
+_RequiredPollForTaskInputRequestTypeDef = TypedDict(
+    "_RequiredPollForTaskInputRequestTypeDef",
+    {
+        "workerGroup": str,
+    },
+)
+_OptionalPollForTaskInputRequestTypeDef = TypedDict(
+    "_OptionalPollForTaskInputRequestTypeDef",
+    {
+        "hostname": str,
+        "instanceIdentity": InstanceIdentityTypeDef,
+    },
+    total=False,
+)
+
+
+class PollForTaskInputRequestTypeDef(
+    _RequiredPollForTaskInputRequestTypeDef, _OptionalPollForTaskInputRequestTypeDef
+):
+    pass
+
+
+ListPipelinesOutputTypeDef = TypedDict(
+    "ListPipelinesOutputTypeDef",
+    {
+        "pipelineIdList": List[PipelineIdNameTypeDef],
+        "marker": str,
+        "hasMoreResults": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+SelectorTypeDef = TypedDict(
+    "SelectorTypeDef",
+    {
+        "fieldName": str,
+        "operator": OperatorTypeDef,
+    },
+    total=False,
+)
+
+ParameterObjectTypeDef = TypedDict(
+    "ParameterObjectTypeDef",
+    {
+        "id": str,
+        "attributes": List[ParameterAttributeTypeDef],
+    },
+)
+
+PutPipelineDefinitionOutputTypeDef = TypedDict(
+    "PutPipelineDefinitionOutputTypeDef",
+    {
+        "validationErrors": List[ValidationErrorTypeDef],
+        "validationWarnings": List[ValidationWarningTypeDef],
+        "errored": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ValidatePipelineDefinitionOutputTypeDef = TypedDict(
+    "ValidatePipelineDefinitionOutputTypeDef",
+    {
+        "validationErrors": List[ValidationErrorTypeDef],
+        "validationWarnings": List[ValidationWarningTypeDef],
+        "errored": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribePipelinesOutputTypeDef = TypedDict(
+    "DescribePipelinesOutputTypeDef",
+    {
+        "pipelineDescriptionList": List[PipelineDescriptionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeObjectsOutputTypeDef = TypedDict(
+    "DescribeObjectsOutputTypeDef",
+    {
+        "pipelineObjects": List[PipelineObjectTypeDef],
+        "marker": str,
+        "hasMoreResults": bool,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
@@ -692,23 +630,65 @@ TaskObjectTypeDef = TypedDict(
         "taskId": str,
         "pipelineId": str,
         "attemptId": str,
-        "objects": Dict[str, "PipelineObjectTypeDef"],
+        "objects": Dict[str, PipelineObjectTypeDef],
     },
     total=False,
 )
 
+QueryTypeDef = TypedDict(
+    "QueryTypeDef",
+    {
+        "selectors": Sequence[SelectorTypeDef],
+    },
+    total=False,
+)
+
+GetPipelineDefinitionOutputTypeDef = TypedDict(
+    "GetPipelineDefinitionOutputTypeDef",
+    {
+        "pipelineObjects": List[PipelineObjectTypeDef],
+        "parameterObjects": List[ParameterObjectTypeDef],
+        "parameterValues": List[ParameterValueTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredPutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_RequiredPutPipelineDefinitionInputRequestTypeDef",
+    {
+        "pipelineId": str,
+        "pipelineObjects": Sequence[PipelineObjectTypeDef],
+    },
+)
+_OptionalPutPipelineDefinitionInputRequestTypeDef = TypedDict(
+    "_OptionalPutPipelineDefinitionInputRequestTypeDef",
+    {
+        "parameterObjects": Sequence[ParameterObjectTypeDef],
+        "parameterValues": Sequence[ParameterValueTypeDef],
+    },
+    total=False,
+)
+
+
+class PutPipelineDefinitionInputRequestTypeDef(
+    _RequiredPutPipelineDefinitionInputRequestTypeDef,
+    _OptionalPutPipelineDefinitionInputRequestTypeDef,
+):
+    pass
+
+
 _RequiredValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
     "_RequiredValidatePipelineDefinitionInputRequestTypeDef",
     {
         "pipelineId": str,
-        "pipelineObjects": Sequence["PipelineObjectTypeDef"],
+        "pipelineObjects": Sequence[PipelineObjectTypeDef],
     },
 )
 _OptionalValidatePipelineDefinitionInputRequestTypeDef = TypedDict(
     "_OptionalValidatePipelineDefinitionInputRequestTypeDef",
     {
-        "parameterObjects": Sequence["ParameterObjectTypeDef"],
-        "parameterValues": Sequence["ParameterValueTypeDef"],
+        "parameterObjects": Sequence[ParameterObjectTypeDef],
+        "parameterValues": Sequence[ParameterValueTypeDef],
     },
     total=False,
 )
@@ -721,30 +701,57 @@ class ValidatePipelineDefinitionInputRequestTypeDef(
     pass
 
 
-ValidatePipelineDefinitionOutputTypeDef = TypedDict(
-    "ValidatePipelineDefinitionOutputTypeDef",
+PollForTaskOutputTypeDef = TypedDict(
+    "PollForTaskOutputTypeDef",
     {
-        "validationErrors": List["ValidationErrorTypeDef"],
-        "validationWarnings": List["ValidationWarningTypeDef"],
-        "errored": bool,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "taskObject": TaskObjectTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
 
-ValidationErrorTypeDef = TypedDict(
-    "ValidationErrorTypeDef",
+_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "_RequiredQueryObjectsInputQueryObjectsPaginateTypeDef",
     {
-        "id": str,
-        "errors": List[str],
+        "pipelineId": str,
+        "sphere": str,
+    },
+)
+_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef = TypedDict(
+    "_OptionalQueryObjectsInputQueryObjectsPaginateTypeDef",
+    {
+        "query": QueryTypeDef,
+        "PaginationConfig": PaginatorConfigTypeDef,
     },
     total=False,
 )
 
-ValidationWarningTypeDef = TypedDict(
-    "ValidationWarningTypeDef",
+
+class QueryObjectsInputQueryObjectsPaginateTypeDef(
+    _RequiredQueryObjectsInputQueryObjectsPaginateTypeDef,
+    _OptionalQueryObjectsInputQueryObjectsPaginateTypeDef,
+):
+    pass
+
+
+_RequiredQueryObjectsInputRequestTypeDef = TypedDict(
+    "_RequiredQueryObjectsInputRequestTypeDef",
     {
-        "id": str,
-        "warnings": List[str],
+        "pipelineId": str,
+        "sphere": str,
+    },
+)
+_OptionalQueryObjectsInputRequestTypeDef = TypedDict(
+    "_OptionalQueryObjectsInputRequestTypeDef",
+    {
+        "query": QueryTypeDef,
+        "marker": str,
+        "limit": int,
     },
     total=False,
 )
+
+
+class QueryObjectsInputRequestTypeDef(
+    _RequiredQueryObjectsInputRequestTypeDef, _OptionalQueryObjectsInputRequestTypeDef
+):
+    pass
